/*
 * Copyright (c) 2003 Patrick van Staveren <pvanstav@cs.wmich.edu>
 * Copyright (c) 2005 Mario Streiber <mario.streiber@gmx.de>
 * Copyright (c) 2006-2009 Landry Breuil (landry at fr.homeunix.org / gaston at gcu.info)
 * Copyright (c) 2005-2009 Kemal Ilgar Eroglu <ilgar_eroglu@yahoo.com> 
 * 
 * This code is licenced under a BSD-style licence.
 * (OpenBSD variant modeled after the ISC licence)
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


/* put the includes */

#include "libcommon.h"
#include "simple-libmpd.h"

#define DEFAULT_MPD_HOST "localhost"
#define DEFAULT_MPD_PORT 6600
#define DIALOG_ENTRY_WIDTH 15
#define STRLENGTH 32

gchar *MpdVersion="0";

typedef struct {
  gchar 	*host;
  gint 		port;
  gchar		*password;
  gboolean	usepass;
  MpdObj 	*mo;
  GtkWidget *playlist;
} mpd_params;

/************************************************************************/
/* Extra stuff                                                          */
/************************************************************************/

gboolean
player_plugin_reconnect (mpd_params *mpddata)
{
   DBG ("!");
   mpd_connect (mpddata->mo);
   if (strlen(mpddata->password))
      mpd_send_password (mpddata->mo);

   return !mpd_check_error (mpddata->mo);
}

static void
playlist_title_dblclicked (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, mpd_params *mpddata)
{
   GtkTreeModel *model;
   GtkTreeIter iter;
   gint id = 0, pos = 0;

   model = gtk_tree_view_get_model(treeview);
   if (gtk_tree_model_get_iter(model, &iter, path))
   {
      gtk_tree_model_get(model, &iter, 2, &pos, 3, &id, -1);
      DBG("Dbl-clicked id %d (pos=%d)",id, pos);
      mpd_player_play_id(mpddata->mo, id);
   }
   gtk_widget_destroy(mpddata->playlist);
   mpddata->playlist = NULL;
}

/************************************************************************/

gboolean player_init (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata; 



	mpddata = (mpd_params *)g_new (mpd_params,1);
	pd->extradata = (gpointer) mpddata;

    mpddata->host = g_strdup(DEFAULT_MPD_HOST);
    mpddata->port = DEFAULT_MPD_PORT;
    mpddata->password = g_strdup("");
	mpddata->playlist = NULL;
	pd->show_pl		= FALSE;
	mpddata->usepass = FALSE;

    player_read_special_options (pd);
	
    mpddata->mo = mpd_new(mpddata->host,mpddata->port,mpddata->password);
	mpd_connect(mpddata->mo);

	if (!mpddata->mo->error) {
		mpd_status_update (mpddata->mo);	
		return TRUE;
	}
	else {
		mpd_disconnect (mpddata->mo);
		return FALSE;
	}
}	

gboolean player_deinit (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	
	if(!pd->is_broken)
		mpd_disconnect (mpddata->mo);

	xmms_plugin_write_config (pd->base, pd);
	
	if(mpddata) {
		mpd_free(mpddata->mo);
		g_free(mpddata->host);
		g_free(mpddata->password);
		g_free(mpddata);
		pd->extradata = NULL;
	}
	
	return TRUE;
}	

void player_save_special_options (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	XfceRc *rc;
	char *file;
	gchar timeout[32];

	g_return_if_fail(pd->base!=NULL && mpddata!=NULL);

	if (!(file = xfce_panel_plugin_save_location (pd->base, TRUE)))
		return;

	rc = xfce_rc_simple_open (file, FALSE);
	g_free (file);

	if (!rc) {
		return;
	}
	/* save mpd host option */
	xfce_rc_write_entry(rc, "mpd_host", mpddata->host);

	/* save mpd port option */
	xfce_rc_write_int_entry(rc, "mpd_port", mpddata->port);

	/* save mpd timeout option */
	/*g_ascii_dtostr (timeout, 30, mpddata->timeout);
	xfce_rc_write_entry(rc, "mpd_timeout", timeout);*/

	/* save mpd password option */
	xfce_rc_write_entry(rc, "mpd_password", mpddata->password);
	
	/* save mpd usepass option */
	xfce_rc_write_bool_entry(rc, "mpd_usepass", mpddata->usepass);
	
	xfce_rc_close(rc);   
	
	//g_fprintf(stderr, "\n****** WROTE OPTS: %s  %d  %d *************",mpddata->host,mpddata->port,mpddata->timeout);
}


void player_read_special_options (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata=(mpd_params *) pd->extradata;
	
	XfceRc *rc;
	char *file;
	gint n;


	if(!pd->extradata) {

		return;
	}	
	
	if ((file = xfce_panel_plugin_lookup_rc_file (pd->base)) != NULL)
	{
		
		rc = xfce_rc_simple_open (file, TRUE);
		g_free (file);

		if (rc != NULL)
		{	

			/* load mpd host option */
			mpddata->host=g_strndup(xfce_rc_read_entry(rc, "mpd_host",DEFAULT_MPD_HOST), 511);
			
			/* load mpd port option */
			mpddata->port = xfce_rc_read_int_entry(rc, "mpd_port",  DEFAULT_MPD_PORT);

			/* load mpd password option */
			mpddata->password = g_strndup(xfce_rc_read_entry(rc, "mpd_password",""), 31);			
			
			/* load mpd usepass option */
			mpddata->usepass = xfce_rc_read_bool_entry(rc, "mpd_usepass", FALSE );

			xfce_rc_close(rc);

		}	

	}
	
}

void player_populate_special_options (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	GtkWidget *ent, *label, *hbox;
	gint att_opts = GTK_SHRINK | GTK_EXPAND | GTK_FILL;


	if(!mpddata) {
		return;
	}

	hbox = gtk_hbox_new (FALSE, 2);
	gtk_box_pack_start(GTK_BOX(pd->spec_opts),hbox, FALSE, FALSE, 2);
	label = gtk_label_new(_("Host"));
	gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
	ent = gtk_entry_new_with_max_length(512);
	pd->spec_opt_widget[0] =(gpointer) ent;
	gtk_entry_set_text (GTK_ENTRY(ent), mpddata->host);
	gtk_box_pack_start (GTK_BOX(hbox), label, TRUE, TRUE, 2);
	gtk_box_pack_start (GTK_BOX(hbox), ent, FALSE, FALSE, 2);


	hbox = gtk_hbox_new (FALSE, 2);
	gtk_box_pack_start(GTK_BOX(pd->spec_opts),hbox, FALSE, FALSE, 2);
	label = gtk_label_new(_("Port"));
	gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
	ent = gtk_spin_button_new_with_range (1,99999,1.0);
	pd->spec_opt_widget[1] = (gpointer) ent;
	gtk_spin_button_set_value (GTK_SPIN_BUTTON(ent), mpddata->port);
	gtk_box_pack_start (GTK_BOX(hbox), label, TRUE, TRUE, 2);
	gtk_box_pack_start (GTK_BOX(hbox), ent, FALSE, FALSE, 2);

	/* Use password option */
	ent=gtk_check_button_new_with_label (_("Use password?"));
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(ent), mpddata->usepass);
	pd->spec_opt_widget[3] = (gpointer) ent;
	gtk_box_pack_start (GTK_BOX(hbox), ent, TRUE, TRUE, 2);
		
	hbox = gtk_hbox_new (FALSE, 2);
	gtk_box_pack_start(GTK_BOX(pd->spec_opts),hbox, FALSE, FALSE, 2);					
	label = gtk_label_new(_("Password"));
	gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
	ent = gtk_entry_new_with_max_length(32);
	pd->spec_opt_widget[2] = (gpointer) ent;
	gtk_entry_set_visibility (GTK_ENTRY(ent), FALSE);
	gtk_entry_set_text (GTK_ENTRY(ent), mpddata->password);
	gtk_box_pack_start (GTK_BOX(hbox), label, TRUE, TRUE, 2);
	gtk_box_pack_start (GTK_BOX(hbox), ent, FALSE, FALSE, 2);
									



	gtk_widget_show_all ((GtkWidget *)pd->spec_opts);

}

gboolean player_update_special_options (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	gboolean reinit = FALSE;


	// Assumed order of pd->spec_opt_widget list members: The widgets for:
	// Host (entry), port (spinbox), passowrd (entry), usepass (checkbutton)
	// See player_populate_special_options above.
	
	if( g_ascii_strcasecmp (mpddata->host, gtk_entry_get_text((GtkEntry *)pd->spec_opt_widget[0]))) {
		reinit= TRUE;
		g_strlcpy (mpddata->host, gtk_entry_get_text((GtkEntry *)pd->spec_opt_widget[0]),512);
	}
	if (mpddata->port != gtk_spin_button_get_value_as_int ((GtkSpinButton *)pd->spec_opt_widget[1])) {
		mpddata->port= gtk_spin_button_get_value_as_int ((GtkSpinButton *)pd->spec_opt_widget[1]);
		reinit= TRUE;
	}
	
	if( g_ascii_strcasecmp (mpddata->password, gtk_entry_get_text((GtkEntry *)pd->spec_opt_widget[2]))) {
		g_strlcpy (mpddata->password, gtk_entry_get_text((GtkEntry *)pd->spec_opt_widget[2]),32);
		reinit = TRUE;
	}
	if (mpddata->usepass != gtk_toggle_button_get_active ((GtkToggleButton *)pd->spec_opt_widget[3])) {
		mpddata->usepass = gtk_toggle_button_get_active ((GtkToggleButton *)pd->spec_opt_widget[3]);
		reinit=TRUE;
	}
	
	if(reinit)
	  
	return reinit;

}

guint player_get_menu_options (gpointer cdata) {

  return ( ITEM_CLEAR | ITEM_REPEAT | ITEM_SHUFFLE | ITEM_VIEW_PL);
  
}


void player_playlist (gpointer cdata, gchar ** list, gint num, gboolean enqueue) {
	
	
	
}


void  player_play (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;

	mpd_player_play (mpddata->mo);

}	


void player_pause (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_player_pause (mpddata->mo);
}


void player_stop (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;	
	mpd_player_stop (mpddata->mo);
	
}

gboolean player_is_playing (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;

	return (mpddata->mo->status == MPD_PLAYER_PLAY || mpddata->mo->status == MPD_PLAYER_PAUSE) ;

}


gboolean player_is_paused (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	
	return (mpddata->mo->status == MPD_PLAYER_PAUSE) ;

}


gint player_get_playlist_pos (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	return mpd_player_get_current_song_pos (mpddata->mo);

}


void player_set_playlist_pos (gpointer cdata, gint pos) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_player_play_pos (mpddata->mo, pos);
	
}


gint player_get_playlist_length (gpointer cdata) {
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	return mpd_playlist_get_playlist_length (mpddata->mo);
}


gint player_get_output_time (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Song* song = mpd_playlist_get_current_song (mpddata->mo);
	
	if (!mpd_status_update(mpddata->mo))
		return mpddata->mo->elapsedTime;
}

void player_jump_to_time (gpointer cdata, gint time) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;

	mpd_player_seek (mpddata->mo, mpd_player_get_current_song_pos (mpddata->mo), time);
}


void player_get_volume (gpointer cdata, gint * vl, gint * vr) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	gint vol;

	
	vol = mpd_status_get_volume(mpddata->mo);
	*vl = vol;
	*vr = vol;


}


void player_set_volume (gpointer cdata, gint vl, gint vr) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
 	mpd_status_set_volume (mpddata->mo, MAX(vl,vr));
 }


gchar * player_get_playlist_file (gpointer cdata, gint pos) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Song* song = mpd_playlist_get_current_song (mpddata->mo);
	
	if (song)
		return song->file;
	
}


gchar * player_get_playlist_title (gpointer cdata, gint pos) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Song* song = mpd_playlist_get_current_song (mpddata->mo);
	
	if (song->title)
		return g_strdup (song->title);
	else 
		return g_path_get_basename (song->file);
}


gint player_get_playlist_time (gpointer cdata, gint pos) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Song* song = mpd_playlist_get_current_song (mpddata->mo);
	
	if (song && !mpd_status_update(mpddata->mo))
		return mpddata->mo->totalTime;
	else return;
}

void player_show_prefs_box (gpointer cdata) {
	
	return;
}

void player_eject (gpointer cdata) {

	return;
}


void player_playlist_prev (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;	

	gint pos= player_get_playlist_pos(cdata)-1;


	if (player_is_playing(cdata)) {
		
		player_set_playlist_pos (cdata, pos);

	} else {
	
		player_set_playlist_pos (cdata, pos);
		mpd_player_stop (mpddata->mo);
	}
	
}


void player_playlist_next (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;

	gint pos=player_get_playlist_pos(cdata);

	
	if (player_is_playing(cdata)) {
		
		if (pos == player_get_playlist_length( cdata)-1)
			pos = 0;
		else 
			pos += 1;	
		
		player_set_playlist_pos (cdata,pos);
		
	} else {
	
		pos += 1;
		player_set_playlist_pos (cdata, pos);
		mpd_player_stop (mpddata->mo);		
	}
	
}


gboolean player_is_running (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_status_update(mpddata->mo);
	
	if (mpddata->mo->status) 
		return TRUE;
	else 
		return FALSE;

}


void  player_quit (gpointer cdata) {
	
	return;
}

void  player_play_pause (gpointer cdata) {
	
}

gchar *  player_get_version (gpointer cdata) {


	return MpdVersion;
}


void  player_playlist_add (gpointer cdata, GList * list) {
	
	/*
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Connection *conn= (mpd_Connection *) mpddata->connection;
	GList *li;
	gchar *fname,*fname2;

	// strip the "file://" prefix, reject url's
	for (li = list; li != NULL; li = g_list_next(li)) {
		fname = (gchar *)li->data;
		
		if(g_strstr_len(fname,8,"url:") == fname || g_strstr_len(fname,8,"http:") == fname)
			continue;
		if ( g_strstr_len(fname,8,"file://") == fname){
			fname+=sizeof("file://")-1;
		}
			
		mpd_sendAddCommand(conn, fname);
		mpd_finishCommand (conn);		

	}	
	*/	
}


void  player_playlist_delete (gpointer cdata, gint pos) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_playlist_delete (mpddata->mo, pos);
}


void  player_main_win_toggle (gpointer cdata, gboolean show) {
	
}


void  player_pl_win_toggle (gpointer cdata, gboolean show) {


	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpc = (mpd_params *) pd->extradata;
	//MpdObj *mo = mpc->mo;
			
	DBG("!");
	GtkWidget *scrolledwin, *treeview;
	GtkListStore *liststore;
	GtkTreeIter iter;
	GtkTreePath *path_to_cur;
	GtkCellRenderer *renderer;
	gchar str[512];
	int current;
	MpdData *mpd_data;

	if (mpc->playlist)
	{
	  gtk_widget_destroy (mpc->playlist);
	  mpc->playlist=NULL;
	  return;
	}
	/* create playlist window only if playlist is not empty */
	if (0 != mpd_playlist_get_playlist_length(mpc->mo))
	{
	  DBG ("Creating playlist window");
	  mpc->playlist = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	  gtk_window_set_default_size(GTK_WINDOW(mpc->playlist), 400, 600);
	  gtk_window_set_icon_name(GTK_WINDOW(mpc->playlist),"xfce-multimedia");
	  gtk_window_set_title(GTK_WINDOW(mpc->playlist),_("Mpd playlist"));
	  g_signal_connect(mpc->playlist, "destroy", G_CALLBACK(gtk_widget_destroyed), &mpc->playlist);
	  scrolledwin = gtk_scrolled_window_new(NULL, NULL);
	  gtk_container_add(GTK_CONTAINER(mpc->playlist),GTK_WIDGET(scrolledwin));

	  treeview = gtk_tree_view_new ();
	  gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(treeview), FALSE);
	  gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(treeview), TRUE);
	  g_signal_connect(treeview, "row-activated", G_CALLBACK(playlist_title_dblclicked), mpc);
	  gtk_container_add(GTK_CONTAINER(scrolledwin),treeview);

	  liststore = gtk_list_store_new(4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT);
	  gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL(liststore));

	  renderer = gtk_cell_renderer_pixbuf_new ();
	  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview), -1, "Icon", renderer, "stock-id", 0, NULL);
	  renderer = gtk_cell_renderer_text_new ();
	  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview), -1, "Title", renderer, "text", 1, NULL);

	  if (!player_plugin_reconnect(mpc))
	  {
		 gtk_widget_destroy(mpc->playlist);
		 mpc->playlist=NULL;
		 return;
	  }

	  current = mpd_player_get_current_song_pos (mpc->mo);
	  DBG ("Current song pos in the list: %d", current);
	  mpd_data = mpd_playlist_get_changes (mpc->mo, -1);
	  DBG ("Got playlist, filling treeview");
	  do
	  {
		 str[0]='\0';
		 format_song_display(mpd_data->song, str);

		 gtk_list_store_append (liststore, &iter);
		 if (current == mpd_data->song->pos)
		 {
			gtk_list_store_set (liststore, &iter, 0, "gtk-media-play", 1, str, 2, mpd_data->song->pos, 3, mpd_data->song->id, -1);
			path_to_cur = gtk_tree_model_get_path(GTK_TREE_MODEL(liststore), &iter);
			gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), path_to_cur, NULL, TRUE, 0.5, 0);
			gtk_tree_view_set_cursor(GTK_TREE_VIEW(treeview), path_to_cur, NULL, FALSE);
			gtk_tree_path_free(path_to_cur);
		 }
		 else
			gtk_list_store_set (liststore, &iter, 0, "gtk-cdrom", 1, str, 2, mpd_data->song->pos, 3, mpd_data->song->id, -1);
	  } while (NULL != (mpd_data = mpd_data_get_next (mpd_data)));
	  gtk_widget_show_all(mpc->playlist);
	}		
			
}


void  player_eq_win_toggle (gpointer cdata, gboolean show) {
	
}


gboolean  player_is_main_win (gpointer cdata) {

}


gboolean  player_is_pl_win (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	
	return (mpddata->playlist != NULL);
}


gboolean  player_is_eq_win (gpointer cdata) {

	
}


void  player_playlist_add_url_string (gpointer cdata, gchar * string) {

	/*
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_Connection *conn= (mpd_Connection *) mpddata->connection;
	
	//g_fprintf(stderr, "\nMark pl_add_url_string ");	
	
	if(g_strstr_len(string,8,"url:") == string || g_strstr_len(string,8,"http:") == string)
		return;
	if ( g_strstr_len(string,8,"file://") == string){
		string+=sizeof("file://")-1;
		//g_fprintf(stderr,"\n\nFile2: %s", string);
	}	

	mpd_sendAddCommand(conn, string);	
	mpd_finishCommand (conn);	
	*/
}

void  player_toggle_repeat (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_player_set_repeat (mpddata->mo, !mpd_player_get_repeat(mpddata->mo));
}

void  player_toggle_shuffle (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_player_set_random (mpddata->mo, !mpd_player_get_random(mpddata->mo));
	
}


gboolean  player_is_repeat (gpointer cdata) {
	
	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	return mpd_player_get_repeat(mpddata->mo);
		
}	


gboolean  player_is_shuffle (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	return mpd_player_get_random(mpddata->mo);			
}

void  player_playlist_clear (gpointer cdata) {

	plugin_data *pd= (plugin_data *) cdata;
	mpd_params *mpddata = (mpd_params *) pd->extradata;
	mpd_playlist_clear(mpddata->mo);			
}
	
void  player_show_jtf_box (gpointer cdata) {
	
}

void player_toggle_aot (gpointer cdata, gboolean ontop) {


}


